@@ -36,7 +36,15 @@ class _PixelDataType(Enum):
 
 class ParametricMap(SOPClass):
 
-    """SOP class for a Parametric Map."""
+    """SOP class for a Parametric Map.
+
+    Note
+    ----
+    This class only supports creation of Parametric Map instances with a
+    value of interest (VOI) lookup table that describes a linear transformation
+    that equally applies to all frames in the image.
+
+    """
 
     def __init__(
         self,
@@ -126,7 +134,7 @@ class ParametricMap(SOPClass):
             used for different representations such as log versus linear scales
             or for different representations in different units.
             If `pixel_array` is a 2D or 3D array and only one channel exists
-            at each spatial image position), then one or more real-world value
+            at each spatial image position, then one or more real-world value
             mappings shall be provided in a flat sequence.
             If `pixel_array` is a 4D array and multiple channels exist at each
             spatial image position, then one or more mappings shall be provided
@@ -135,22 +143,22 @@ class ParametricMap(SOPClass):
 
             In some situations the mapping may be difficult to describe (e.g., in
             case of a transformation performed by a deep convolutional neural
-            network). The real-world value mapping may simply describe an
+            network). The real-world value mapping may then simply describe an
             identity function that maps stored values to unit-less real-world
             values.
         window_center: Union[int, float, None], optional
-            Window center for rescaling stored values for display purposes by
-            applying a linear transformation function. For example, in case of
-            floating-point values in the range ``[0.0, 1.0]``, the window
-            center may be ``0.5``, in case of floating-point values in the
-            range ``[-1.0, 1.0]`` the window center may be ``0.0``, in case
+            Window center (intensity) for rescaling stored values for display
+            purposes by applying a linear transformation function. For example,
+            in case of floating-point values in the range ``[0.0, 1.0]``, the
+            window center may be ``0.5``, in case of floating-point values in
+            the range ``[-1.0, 1.0]`` the window center may be ``0.0``, in case
             of unsigned integer values in the range ``[0, 255]`` the window
             center may be ``128``.
         window_width: Union[int, float, None], optional
-            Window width for rescaling stored values for display purposes by
-            applying a linear transformation function. For example, in case of
-            floating-point values in the range ``[0.0, 1.0]``, the window
-            width may be ``1.0``, in case of floating-point values in the
+            Window width (contrast) for rescaling stored values for display
+            purposes by applying a linear transformation function. For example,
+            in case of floating-point values in the range ``[0.0, 1.0]``, the
+            window width may be ``1.0``, in case of floating-point values in the
             range ``[-1.0, 1.0]`` the window width may be ``2.0``, and in
             case of unsigned integer values in the range ``[0, 255]`` the
             window width may be ``256``. In case of unbounded floating-point
@@ -578,7 +586,7 @@ class ParametricMap(SOPClass):
         voi_lut_item = Dataset()
         voi_lut_item.WindowCenter = window_center
         voi_lut_item.WindowWidth = window_width
-        voi_lut_item.VOILUTFunction = "LINEAR_EXACT"
+        voi_lut_item.VOILUTFunction = 'LINEAR'
         sffg_item.FrameVOILUTSequence = [voi_lut_item]
 
         # Parametric Map Frame Type
